@@ -6,13 +6,16 @@ use strict;
 use XML::TMX::Writer;
 use Exporter ();
 
-use vars qw(@ISA @EXPORT_OK);
+use vars qw(@ISA @EXPORT_OK $VERSION);
 
+$VERSION = '0.29';
 @ISA = 'Exporter';
 @EXPORT_OK = qw(&new &parse_dir &create_tmx &clean_tmx);
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 XML::TMX::FromPO - Generates a TMX file from a group of PO files
@@ -97,11 +100,19 @@ sub rec_get_po {
             __processa($self, $file, $lang);
          }
       }
+      elsif($file =~ /(.*)\.(\w+)\.(po|messages)$/) {
+         my $lang = lc($lan1);
+         ## ??? my $lang = "\L$2";
+
+         if(!defined($self->{LANG}) || __check_lang($self, $lang)) {
+            __processa($self, $file, $lang);
+         }
+      }
       elsif(-d $file) {
          rec_get_po($self,$file,$lan1)
       }
       else {
-         ## warn ("$file ... no tem lingua\n") if($self->{DEBUG});
+         ## warn ("$file ... não tem lingua\n") if($self->{DEBUG});
       }
     }
    }
@@ -126,15 +137,21 @@ sub parse_dir {
    # check if directory is readable
    die("$dir is not a readable directory\n") unless(-d $dir);
 
-   for my $file (<$dir/*.po>) {
-      if($file =~ /(\w+)\.po$/) {
+   for my $file ((<$dir/*.po>),(<$dir/*.messages>)) {
+      if($file =~ /(\w+)\.(po|messages)$/) {
          my $lang = "\L$1";
 
+         if(!defined($self->{LANG}) || __check_lang($self, $lang)) {
+            __processa($self, $file, $lang);
+         }
+      } elsif($file =~ /(.*)\.(\w+)\.(po|messages)$/) {
+         my $lang = "\L$2";
+
          if(!defined($self->{LANG}) || __check_lang($self, $lang)) {
             __processa($self, $file, $lang);
          }
       } else {
-         warn ("$file ... no tem lingua\n") if($self->{DEBUG});
+         warn ("$file ... não tem lingua\n") if($self->{DEBUG});
       }
    }
 
@@ -282,26 +299,26 @@ sub __processa {
 sub __limpa {
    my $self = shift;
 
-   # possveis limpezas
-   # (1) eliminar tradues que sejam igual ao original
-   # (2) eliminar strings que no contenham pelo menos 2 letras
+   # possíveis limpezas
+   # (1) eliminar traduções que sejam igual ao original
+   # (2) eliminar strings que não contenham pelo menos 2 letras
    #     consecutivas
-   # (3) eliminar frases que fiquem sem tradues
+   # (3) eliminar frases que fiquem sem traduções
    #
-   # um teste realizado com os po's do evolution mostrou uma reduo do
-   # ficheiro final de 12M para 8,6M, uma anlise com o diff aos dumps
+   # um teste realizado com os po's do evolution mostrou uma redução do
+   # ficheiro final de 12M para 8,6M, uma análise com o diff aos dumps
    # permitiu ver que grande parte do ''lixo'' eram de (1)
 
    for my $h1 (keys %{$self->{TMX}}) {
       if($h1 =~ /[a-z][a-z]/i) {
          for my $h2 (keys %{$self->{TMX}{$h1}}) {
-            # optimizao (1)
+            # optimização (1)
             delete($self->{TMX}{$h1}{$h2}) if($h2 !~ /^en/i && $h1 eq $self->{TMX}{$h1}{$h2});
          }
-         # optimizao (3)
+         # optimização (3)
          delete($self->{TMX}{$h1}) unless(keys %{$self->{TMX}{$h1}});
       } else {
-         # optimizao (2)
+         # optimização (2)
          delete($self->{TMX}{$h1});
       }
    }
